@@ -17,7 +17,7 @@
 //! use-case. Subtle implementation details may have catastrophic implications
 //! for the security of your cryptosystem, and users are advised to engage a
 //! cryptographer before making use of this module.
-
+#![allow(clippy::just_underscores_and_digits)]
 pub mod c_abi;
 pub mod curves;
 
@@ -61,7 +61,7 @@ macro_rules! copy_to_cryptoram {
 
 /// Struct representing a PUKCC peripheral.
 ///
-/// It provides an access to cryptograhic algorithms in a safe, high-level
+/// It provides an access to cryptographic algorithms in a safe, high-level
 /// manner
 pub struct Pukcc {
     __: (),
@@ -164,8 +164,6 @@ impl Pukcc {
 
     /// Service generating an ECDSA signature.
     ///
-    /// Unsafe: `k` value must be cryptograhically secure.
-    ///
     /// GF(p) service. GF(2^n) variant is not implemented -- use low-level API.
     ///
     /// Input parameters:
@@ -202,6 +200,10 @@ impl Pukcc {
     /// multiplication can become reversible (lack of _trapdoor function_
     /// property) and an attacker might be able to reverse engineer a
     /// `private_key` from a `signature`.
+    ///
+    /// # Safety
+    ///
+    /// `k` value must be cryptographically secure.
     pub unsafe fn zp_ecdsa_sign_with_raw_k<C: Curve>(
         &self,
         signature: &mut [u8],
@@ -219,10 +221,7 @@ impl Pukcc {
         private_key: &[u8],
         k: &[u8],
     ) -> Result<(), EcdsaSignFailure> {
-        match C::verify_curve() {
-            Err(e) => return Err(EcdsaSignFailure::InvalidCurve(e)),
-            _ => {}
-        };
+        C::verify_curve().map_err(EcdsaSignFailure::InvalidCurve)?;
 
         if signature.len() != (2 * C::MOD_LENGTH).into() {
             return Err(EcdsaSignFailure::WrongInputParameterLength {
@@ -268,7 +267,7 @@ impl Pukcc {
         );
         let mut crypto_ram = unsafe { c_abi::CryptoRam::new() };
         // 32-byte padding with zeroes on a MSB side of every parameter is required by
-        // PUKCC algorithms. Little endianess requires padding *after* a parameter
+        // PUKCC algorithms. Little endianness requires padding *after* a parameter
         // as MSB is placed on high addresses.
 
         // 32-byte zero padding for curve parameters should be included in original
@@ -368,10 +367,7 @@ impl Pukcc {
         hash: &[u8],
         public_key: &[u8],
     ) -> Result<(), EcdsaSignatureVerificationFailure> {
-        match C::verify_curve() {
-            Err(e) => return Err(EcdsaSignatureVerificationFailure::InvalidCurve(e)),
-            _ => {}
-        };
+        C::verify_curve().map_err(EcdsaSignatureVerificationFailure::InvalidCurve)?;
 
         let (
             modulo_p,
@@ -414,7 +410,7 @@ impl Pukcc {
         }
         let mut crypto_ram = unsafe { c_abi::CryptoRam::new() };
         // 32-byte padding with zeroes on a MSB side of every parameter is required by
-        // PUKCC algorithms. Little endianess requires padding *after* a parameter
+        // PUKCC algorithms. Little endianness requires padding *after* a parameter
         // as MSB is placed on high addresses.
 
         // 32-byte zero padding for curve parameters should be included in original
@@ -624,7 +620,7 @@ impl Pukcc {
 
         let mut crypto_ram = unsafe { c_abi::CryptoRam::new() };
         // 32-byte padding with zeroes on a MSB side of every parameter is required by
-        // PUKCC algorithms (unless said otherwise). Little endianess requires padding
+        // PUKCC algorithms (unless said otherwise). Little endianness requires padding
         // *after* a parameter as MSB is placed on high addresses.
         copy_to_cryptoram! {
             crypto_ram,
@@ -708,7 +704,7 @@ impl Pukcc {
 
         // Even though documentation says that CNS occupies len(modulus) + 12 of space,
         // it is only needed for computation, 7 MSB bytes are zeroes. This distinction
-        // between lenghts allows to skip these 7 MSB zero bytes.
+        // between lengths allows to skip these 7 MSB zero bytes.
         let cns_length = modulus.len() + 12;
         let actual_cns_length = modulus.len() + 5;
 
@@ -771,7 +767,7 @@ pub enum EcdsaSignFailure {
         expected_length: usize,
         actual_length: usize,
     },
-    InvalidCurve(curves::CurveVerficationFailure),
+    InvalidCurve(curves::CurveVerificationFailure),
     BasePointZCoordinateIsNotZero,
     ServiceFailure(PukclReturnCode),
 }
@@ -786,11 +782,11 @@ pub enum EcdsaSignatureVerificationFailure {
         expected_length: usize,
         actual_length: usize,
     },
-    InvalidCurve(curves::CurveVerficationFailure),
+    InvalidCurve(curves::CurveVerificationFailure),
     ServiceFailure(PukclReturnCode),
 }
 
-/// An error type specifing an expected length of a slice in question
+/// An error type specifying an expected length of a slice in question
 #[allow(missing_docs)]
 #[derive(Debug)]
 pub enum ExpectedLengthError {
@@ -913,7 +909,7 @@ impl core::convert::From<c_abi::PukclReturnCode> for PukclReturnCode {
             0xC012 => Severe(PukclReturnCodeSevere::ParamNotInRam),
             0xC013 => Severe(PukclReturnCodeSevere::ParamNotInCpuram),
             0xC014 => Severe(PukclReturnCodeSevere::ParamWrongLength),
-            0xC015 => Severe(PukclReturnCodeSevere::ParamBadAlignement),
+            0xC015 => Severe(PukclReturnCodeSevere::ParamBadAlignment),
             0xC016 => Severe(PukclReturnCodeSevere::ParamXBiggerThanY),
             0xC017 => Severe(PukclReturnCodeSevere::ParamLengthTooSmall),
             0xC101 => Severe(PukclReturnCodeSevere::DivisionByZero),
@@ -951,7 +947,7 @@ impl core::convert::From<PukclReturnCode> for c_abi::PukclReturnCode {
             Severe(PukclReturnCodeSevere::ParamNotInRam) => 0xC012,
             Severe(PukclReturnCodeSevere::ParamNotInCpuram) => 0xC013,
             Severe(PukclReturnCodeSevere::ParamWrongLength) => 0xC014,
-            Severe(PukclReturnCodeSevere::ParamBadAlignement) => 0xC015,
+            Severe(PukclReturnCodeSevere::ParamBadAlignment) => 0xC015,
             Severe(PukclReturnCodeSevere::ParamXBiggerThanY) => 0xC016,
             Severe(PukclReturnCodeSevere::ParamLengthTooSmall) => 0xC017,
             Severe(PukclReturnCodeSevere::DivisionByZero) => 0xC101,
@@ -1019,7 +1015,7 @@ pub enum PukclReturnCodeSevere {
     ParamNotInRam,
     ParamNotInCpuram,
     ParamWrongLength,
-    ParamBadAlignement,
+    ParamBadAlignment,
     ParamXBiggerThanY,
     ParamLengthTooSmall,
     DivisionByZero,
